ParamsMap

Struct ParamsMap 

pub struct ParamsMap(/* private fields */);
A key-value map of the current named route params and their values.

Implementations

Source

impl ParamsMap

pub fn new() -> Self

Creates an empty map.

pub fn with_capacity(capacity: usize) -> Self

Creates an empty map with the given capacity.

pub fn insert(&mut self, key: impl Into<Cow<'static, str>>, value: String)

Inserts a value into the map.

If a value with that key already exists, the new value will be added to it. To replace the value instead, see replace.

pub fn replace(&mut self, key: impl Into<Cow<'static, str>>, value: String)

Inserts a value into the map, replacing any existing value for that key.

pub fn get(&self, key: &str) -> Option<String>

Gets the most-recently-added value of this param from the map.

pub fn get_all(&self, key: &str) -> Option<Vec<String>>

Gets all references to a param of this name from the map.

pub fn latest_values(&self) -> ParamsMapIterRef<'_>

Gets an iterator for all the most-recently-added values on the map

pub fn get_str(&self, key: &str) -> Option<&str>

Gets a reference to the most-recently-added value of this param from the map.

pub fn remove(&mut self, key: &str) -> Option<Vec<String>>

Removes a value from the map.

pub fn to_query_string(&self) -> String

Converts the map to a query string.