pub struct ParamsMap(/* private fields */);Expand description
A key-value map of the current named route params and their values.
Implementations
Sourceimpl ParamsMap
impl ParamsMap
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates an empty map with the given capacity.
Sourcepub fn insert(&mut self, key: impl Into<Cow<'static, str>>, value: String)
pub fn insert(&mut self, key: impl Into<Cow<'static, str>>, value: String)
Inserts a value into the map.
If a value with that key already exists, the new value will be added to it.
To replace the value instead, see replace.
Sourcepub fn replace(&mut self, key: impl Into<Cow<'static, str>>, value: String)
pub fn replace(&mut self, key: impl Into<Cow<'static, str>>, value: String)
Inserts a value into the map, replacing any existing value for that key.
Sourcepub fn get(&self, key: &str) -> Option<String>
pub fn get(&self, key: &str) -> Option<String>
Gets the most-recently-added value of this param from the map.
Sourcepub fn get_all(&self, key: &str) -> Option<Vec<String>>
pub fn get_all(&self, key: &str) -> Option<Vec<String>>
Gets all references to a param of this name from the map.
Sourcepub fn latest_values(&self) -> ParamsMapIterRef<'_> ⓘ
pub fn latest_values(&self) -> ParamsMapIterRef<'_> ⓘ
Gets an iterator for all the most-recently-added values on the map
Sourcepub fn get_str(&self, key: &str) -> Option<&str>
pub fn get_str(&self, key: &str) -> Option<&str>
Gets a reference to the most-recently-added value of this param from the map.
Sourcepub fn to_query_string(&self) -> String
pub fn to_query_string(&self) -> String
Converts the map to a query string.